@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8, vim: expandtab:ts=4 -*-
 
-from .logger import Logger
+from .logger import Logger, DummyLogger
 from .version import __version__
 
-__all__ = [Logger.__name__, __version__]
+__all__ = [Logger.__name__, DummyLogger.__name__, __version__]
